@@ -14,6 +14,8 @@
 #include "xf86_OSproc.h"
 #include "xf86Resources.h"
 
+#include <X11/extensions/panoramiXproto.h>
+
 #include "compiler.h"	        /* inb/outb */
 
 #include "xf86PciInfo.h"	/* pci vendor id */
@@ -23,7 +25,6 @@
 
 #include "vgaHW.h"		/* VGA hardware */
 #include "fb.h"
-#include "xaa.h"
 
 #include "xf86cmap.h"		/* xf86HandleColormaps */
 
@@ -31,8 +32,6 @@
 #include "svga_reg.h"
 #include "svga_struct.h"
 
-#include "offscreen_manager.h"
-
 /* Arbitrarily choose max cursor dimensions.  The emulation doesn't care. */
 #define MAX_CURS        32
 
@@ -52,6 +51,8 @@ typedef struct {
     CARD32 svga_reg_id;
 } VMWARERegRec, *VMWARERegPtr;
 
+typedef xXineramaScreenInfo VMWAREXineramaRec, *VMWAREXineramaPtr;
+
 typedef struct {
     EntityInfoPtr pEnt;
     pciVideoPtr PciInfo;
@@ -77,7 +78,6 @@ typedef struct {
     VMWARERegRec SavedReg;
     VMWARERegRec ModeReg;
 
-    DisplayModePtr initialMode;
     DisplayModePtr dynMode1;
     DisplayModePtr dynMode2;
 
@@ -103,7 +103,6 @@ typedef struct {
 
     unsigned char* mmioVirtBase;
     CARD32* vmwareFIFO;
-    Bool canPitchLock;
 
     xf86CursorInfoPtr CursorInfoRec;
     struct {
@@ -122,21 +121,16 @@ typedef struct {
     ScreenRec ScrnFuncs;
 
     /*
-     * XAA info rec and misc storage
+     * Xinerama state
      */
-    XAAInfoRecPtr xaaInfo;
-    int xaaFGColor;
-    int xaaBGColor;
-    int xaaRop;
+    Bool xinerama;
+    Bool xineramaStatic;
 
-    unsigned char* xaaColorExpScanLine[1];
-    unsigned int xaaColorExpSize; /* size of current scan line in DWords */
+    VMWAREXineramaPtr xineramaState;
+    unsigned int xineramaNumOutputs;
 
-    Heap* heap;
-    SVGASurface* frontBuffer;
-
-    SVGASurface* curPict;
-    int op;
+    VMWAREXineramaPtr xineramaNextState;
+    unsigned int xineramaNextNumOutputs;
 
 } VMWARERec, *VMWAREPtr;
 
@@ -175,8 +169,6 @@ static __inline ScrnInfoPtr infoFromScreen(ScreenPtr s) {
 
 #define MOUSE_ID 1
 
-extern const char *vmwareXaaSymbols[];
-
 /*#define DEBUG_LOGGING*/
 #ifdef DEBUG_LOGGING
 # define VmwareLog(args) ErrorF args
@@ -209,6 +201,13 @@ void vmwareSendSVGACmdUpdate(
    VMWAREPtr pVMWARE, BoxPtr pBB
    );
 
+DisplayModeRec *VMWAREAddDisplayMode(
+    ScrnInfoPtr pScrn,
+    const char *name,
+    int width,
+    int height
+   );
+
 /* vmwarecurs.c */
 Bool vmwareCursorInit(
    ScreenPtr pScr
@@ -234,21 +233,10 @@ void vmwareCursorHookWrappers(
    );
 
 
-/* vmwarexaa.c */
-Bool vmwareXAAScreenInit(
-   ScreenPtr pScreen
-   );
-
-Bool vmwareXAAModeInit(
-    ScrnInfoPtr pScrn, DisplayModePtr mode
-    );
-
-void vmwareXAACloseScreen(
-   ScreenPtr pScreen
-   );
-
-/* vmware_ctl.c */
+/* vmwarectrl.c */
 void VMwareCtrl_ExtInit(ScrnInfoPtr pScrn);
 
+/* vmwarexinerama.c */
+void VMwareXinerama_ExtInit(ScrnInfoPtr pScrn);
 
 #endif
